import request from '@/utils/request'

// 查询班级管理列表
export function listClass(query) {
  return request({
    url: '/custom/class/list',
    method: 'get',
    params: query
  })
}

// 查询班级管理详细
export function getClass(classId) {
  return request({
    url: '/custom/class/' + classId,
    method: 'get'
  })
}

// 新增班级管理
export function addClass(data) {
  return request({
    url: '/custom/class',
    method: 'post',
    data: data
  })
}

// 修改班级管理
export function updateClass(data) {
  return request({
    url: '/custom/class/'+data.classId,
    method: 'put',
    data: data
  })
}

// 删除班级管理
export function delClass(classId) {
  return request({
    url: '/custom/class/' + classId,
    method: 'delete'
  })
}




// 查询小组管理列表
export function listGroup(query) {
  return request({
    url: '/custom/group/list',
    method: 'get',
    params: query
  })
}

// 删除小组管理
export function delGroup(groupId) {
  return request({
    url: '/custom/group/' + groupId,
    method: 'delete'
  })
}

// 新增小组管理
export function addGroup(data) {
  return request({
    url: '/custom/group',
    method: 'post',
    data: data
  })
}

// 查询小组管理详细
export function getGroup(groupId) {
  return request({
    url: '/custom/group/' + groupId,
    method: 'get'
  })
}

// 修改小组管理
export function updateGroup(data) {
  return request({
    url: '/custom/group/' + data.groupId,
    method: 'put',
    data: data
  })
}
