<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="班级名称" prop="className">
        <el-input
          v-model="queryParams.className"
          placeholder="请输入班级名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="状态" prop="status">
        <el-select v-model="queryParams.status" placeholder="请选择状态" clearable>
          <el-option
            v-for="dict in dict.type.sys_normal_disable"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['custom:class:add']"
        >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['custom:class:edit']"
        >修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['custom:class:remove']"
        >删除
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['custom:class:export']"
        >导出
        </el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="classList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center"/>
      <el-table-column label="班级ID" align="center" prop="classId"/>
      <el-table-column label="班级名称" align="center" prop="className"/>
      <el-table-column label="状态" align="center" prop="status">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.sys_normal_disable" :value="scope.row.status"/>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['custom:class:edit']"
          >修改
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['custom:class:remove']"
          >删除
          </el-button>
          <el-button
            type="primary"
            icon="el-icon-edit"
            circle
            @click="handleShowGroup(scope.row)"
            v-hasPermi="['custom:group:list']"
          >查看班级内小组
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="班级名称" prop="className">
          <el-input v-model="form.className" placeholder="请输入班级名称"/>
        </el-form-item>
        <el-form-item label="状态" prop="status">
          <el-radio-group v-model="form.status">
            <el-radio
              v-for="dict in dict.type.sys_normal_disable"
              :key="dict.value"
              :label="dict.value"
            >{{ dict.label }}
            </el-radio>
          </el-radio-group>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>

    <!--  小组列表的外层对话框  -->
    <el-dialog :title="title" :visible.sync="outerVisible">

      <!-- 添加小组 对话框 -->
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleGroupAdd"
          v-hasPermi="['custom:group:add']"
        >添加班级内小组
        </el-button>
      </el-col>


      <!--      {{ groupList }}-->
      <el-table v-loading="loading" :data="groupList">
        <el-table-column label="小组ID" align="center" prop="groupId"/>
        <!--        <el-table-column label="班级ID" align="center" prop="classId"/>-->
        <el-table-column label="小组名称" align="center" prop="groupName"/>
        <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
          <template slot-scope="scope">
            <el-button
              size="mini"
              type="text"
              icon="el-icon-edit"
              @click="handleGroupUpdate(scope.row)"
              v-hasPermi="['custom:group:edit']"
            >修改
            </el-button>
            <el-button
              size="mini"
              type="text"
              icon="el-icon-delete"
              @click="handleGroupDelete(scope.row)"
              v-hasPermi="['custom:group:remove']"
            >删除
            </el-button>
          </template>
        </el-table-column>
      </el-table>

      <el-dialog
        width="50%"
        :title="innerTitle"
        :visible.sync="innerVisible"
        append-to-body>

        <el-form ref="groupForm" :model="form" :rules="groupRules" label-width="80px">
          <el-form-item label="小组名称" prop="groupName">
            <el-input v-model="form.groupName" placeholder="请输入小组名称"/>
          </el-form-item>
        </el-form>

        <div slot="footer" class="dialog-footer">
          <el-button type="primary" @click="submitGroupForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>

      </el-dialog>
    </el-dialog>
  </div>
</template>

<script>
import {
  addClass,
  addGroup,
  delClass,
  delGroup,
  getClass,
  getGroup,
  listClass,
  listGroup,
  updateClass,
  updateGroup
} from "@/api/custom/class";

export default {
  name: "Class",
  dicts: ['sys_normal_disable'],
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 班级管理表格数据
      classList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        className: null,
        status: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        className: [
          {required: true, message: "班级名称不能为空", trigger: "blur"}
        ],
        status: [
          {required: true, message: "状态不能为空", trigger: "change"}
        ]
      },


      //小组管理的数据

      //外层对话框
      outerVisible: false,
      //内层对话框
      innerVisible: false,
      /** 内层主题 */
      innerTitle: "",
      // 小组管理表格数据
      groupList: [],
      // 小组表单校验
      groupRules: {
        groupName: [
          {required: true, message: "小组名称不能为空", trigger: "blur"}
        ],
      },


    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询班级管理列表 */
    getList() {
      this.loading = true;
      listClass(this.queryParams).then(response => {
        this.classList = response.data.rows;
        this.total = response.data.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      // this.outerVisible = false;
      this.innerVisible = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        classId: null,
        className: null,
        status: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,

        groupId: null,
        groupName: null,

      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.classId)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加班级管理";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const classId = row.classId || this.ids
      getClass(classId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改班级管理";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.classId != null) {
            updateClass(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addClass(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const classIds = row.classId || this.ids;
      this.$modal.confirm('是否确认删除班级管理编号为"' + classIds + '"的数据项？').then(function () {
        return delClass(classIds);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {
      });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('custom/class/export', {
        ...this.queryParams
      }, `class_${new Date().getTime()}.xlsx`)
    },


    //小组管理

    /** 查看班级内小组 */
    handleShowGroup(row) {
      this.outerVisible = true;
      //将班级ID存入表单中，方便利用
      this.form.classId = row.classId;
      this.form.className = row.className;

      this.title = "管理" + this.form.className + "班级小组";

      listGroup({classId: this.form.classId}).then(response => {
        this.groupList = response.data;
        this.loading = false;
      });
    },

    /** 删除小组 */
    handleGroupDelete(row) {
      //先把班级ID提取出来，防止删除后，查询的是全部小组的情况
      let classId = this.form.classId;

      this.$modal.confirm('是否确认删除小组编号为"' + row.groupId + '"的数据项？').then(function () {
        return delGroup(row.groupId);
      }).then(() => {
        listGroup({classId: classId}).then(response => {
          this.groupList = response.data;
          this.loading = false;
        });
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {
      });
    },

    /** 新增小组 */
    handleGroupAdd() {
      this.innerVisible = true;
      this.innerTitle = "添加小组";
      //先把班级ID提取出来
      let classId = this.form.classId;
      //再重置表单
      this.reset();
      //再把班级ID进行赋值
      this.form.classId = classId;
    },

    /** 修改小组 */
    handleGroupUpdate(row) {
      getGroup(row.groupId).then(response => {
        this.form = response.data;
        this.innerVisible = true;
        this.innerTitle = "编辑小组";
      });
    },

    /** 提交小组管理的表单 */
    submitGroupForm() {
      this.$refs["groupForm"].validate(valid => {
        if (valid) {
          this.$modal.msgSuccess(valid);
          if (this.form.groupId != null) {
            updateGroup(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.innerVisible = false;
              listGroup({classId: this.form.classId}).then(response => {
                this.groupList = response.data;
                this.loading = false;
              });
            });
          } else {
            addGroup(this.form).then().then(response => {
              this.$modal.msgSuccess("新增成功");
              this.innerVisible = false;
              listGroup({classId: this.form.classId}).then(response => {
                this.groupList = response.data;
                this.loading = false;
              });
            });
          }
        }
      });
    }

  }
};
</script>
